@@ -116,7 +116,12 @@ class SQL:
         for col in columns:
             processed_columns.append(
                 th.resolve_references(
-                    col, options={"alias_column": True, "alias_table": True, bypass_on_error=True}
+                    col,
+                    options={
+                        "alias_column": True,
+                        "alias_table": True,
+                        "bypass_on_error": True,
+                    },
                 )
             )
 
@@ -854,7 +859,6 @@ class SQL:
             if join:
                 sql.append(join)
             column = tx.table(table).column(column_name)
-            print(column)
             if not column.exists():
                 raise Exception(
                     f"Column {column_name} does not exist in table {table}."
